@@ -4,18 +4,12 @@ const double MatOp_symmatrix::BLAS_alpha = 1.0;
 const int MatOp_symmatrix::BLAS_one = 1;
 const double MatOp_symmatrix::BLAS_zero = 0.0;
 
-MatOp_symmatrix::MatOp_symmatrix(SEXP mat_, char uplo_, double sigma_,
+MatOp_symmatrix::MatOp_symmatrix(SEXP mat_, int n_, char uplo_, double sigma_,
                                  bool needSolve_) :
-    A_pntr(REAL(mat_)), A(NULL, 1, 1), uplo(uplo_),
+    MatOp(n_, n_, sigma_, 0.0, true, needSolve_),
+    A_pntr(REAL(mat_)), A(A_pntr, n, n), uplo(uplo_),
     x_vec(NULL, n), y_vec(NULL, n)
 {
-    m = n = (int) sqrt(double(LENGTH(mat_)));
-    new (&A) MapMat(A_pntr, n, n);
-    sigmar = sigma_;
-    sigmai = 0;
-    canTprod = true;
-    canSolve = needSolve_;
-
     if(!needSolve_)  return;
 
     // Subtract the diagonal elements by sigma, i.e., A - sigma * I
@@ -51,7 +45,7 @@ void MatOp_symmatrix::tprod(double *x_in, double *y_out)
 void MatOp_symmatrix::shiftSolve(double *x_in, double *y_out)
 {
     if(!canSolve)
-        Rcpp::stop("this matrix doesn't support solving linear equation");
+        Rcpp::stop("this matrix does not support solving linear equation");
 
     new (&x_vec) MapVec(x_in, n);
     new (&y_vec) MapVec(y_out, n);
